# khmer-nlp

## Installation
```
pip install khmernlp
```

## Usage

```python
# Tokenize and part-of-speech tagging
khmernlp.tokenize([
    "ពាក្យថាអង្គរ តាមវចនានុក្រមរបស់លោកគ្រូ ពៅ សាវរស អង្គរមកពីពាក្យសំស្ដ្រ នគរ មានន័យថា ទីក្រុង រាជធានី អាណាចក្រ",
    "ប្រាសាទអង្គរវត្ត ឬប្រាសាទអង្គរតូចមានទីតាំងស្ថិតនៅភាគខាងជើងនៃក្រុងសៀមរាបនៃខេត្តសៀមរាប"
])
```